### translate_geometry

Translate a geometry by x/y(/z) offsets.

- Tool: `translate_geometry`

Parameters

- geometry (string, WKT)
- xoff (number)
- yoff (number)
- zoff (number, default 0.0)

Returns

- geometry (string, WKT), status, message
